
Insecure internal communication.
-------

**Description:**

Whenever organisations communicatie by means of unencrypted connections, an attacker 
could easily sniff these unsecure lines and gain sensitive information.


**Solution:**

Use for all internal communication channels encryption.

	